Welcome to earthkit-regrids's documentation
======================================================

.. warning::

    This project is **BETA** and will be **Experimental** for the foreseeable future. Interfaces and functionality are likely to change, and the project itself may be scrapped. **DO NOT** use this software in any project/software that is operational.


**earthkit-regrid** is a Python package for regridding.

.. toctree::
   :maxdepth: 1
   :caption: Examples
   :titlesonly:

   examples

.. toctree::
   :maxdepth: 1
   :caption: Installation

   install
   development
   licence


Indices and tables
==================

* :ref:`genindex`

.. * :ref:`modindex`
.. * :ref:`search`
